fequency_of_subtype: Compute the frequency of subtype prediction

Description Usage Arguments Value

View source: R/frequency_of_subtype.R

Description

This function computes, for each sample and each possible subtype, the fraction of kTSP models in the family that predict this subtype assignment

Usage

1

Arguments

SPI

A tibble with columns sample, subtype_prediction, index, as produced by make_subtype_predictions

Value

A tibble with columns sample, subtype_prediction, frequency. We call this object SPF, for subtype prediction frequency


sbuechler/BCCSclassifier documentation built on Dec. 22, 2021, 10:19 p.m.