make_subtype_predictions: Predict subtype assignments, by index

Description Usage Arguments Details Value

View source: R/subtype_prediction.R

Description

This function selects the subtype that wins the most pairwise competitions, for each kTSP model in the family

Usage

1

Arguments

PPI

A tibble with columns sample, pair, pairwise_prediction, index, as produced by the make_pairwise_predictions function.

Details

Predicts, for each sample and kTSP model, the best subtype using the pairwise test results in the given kTSP model

Value

A tibble with columns sample, subtype_prediction, index, that we consider an SPI object, short for subtype prediction - indexed


sbuechler/BCCSclassifier documentation built on Dec. 22, 2021, 10:19 p.m.