Description Usage Arguments Value
View source: R/frequency_of_subtype.R
This function computes, for each sample and each possible subtype, the fraction of kTSP models in the family that predict this subtype assignment
1 | fequency_of_subtype(SPI)
|
SPI |
A tibble with columns sample, subtype_prediction, index, as produced
by |
A tibble with columns sample, subtype_prediction, frequency. We call this object SPF, for subtype prediction frequency
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.