Description Usage Arguments Details Value
View source: R/subtype_prediction.R
This function selects the subtype that wins the most pairwise competitions, for each kTSP model in the family
1 |
PPI |
A tibble with columns sample, pair, pairwise_prediction, index,
as produced by the |
Predicts, for each sample and kTSP model, the best subtype using the pairwise test results in the given kTSP model
A tibble with columns sample, subtype_prediction, index, that we consider an SPI object, short for subtype prediction - indexed
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.